Description Usage Arguments Value Examples
Creates the initial population.
1 | initialize(Y, X, P, regType = "lm", family = "gaussian", seed = 1)
|
Y |
The response vector as passed into select. |
X |
The feature matrix as passed into select. |
P |
The size of the population as passed or determined in select. |
regType |
The type of regression, either 'lm' or 'glm'. |
family |
The family for 'glm'. |
seed |
The seed for reproducibility. |
A list of the P generated candidate solutions where each entry of the list contains
variables: The variables that were
selected for the population.
fit: The lm or glm object of the fit with the
above variables.
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.